@@ -1,11 +1,28 @@
 from __future__ import annotations
 
 import abc
-from typing import Literal, cast, overload
+from typing import TYPE_CHECKING, Literal, cast, overload
+from warnings import deprecated
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
 
 
 class Env(abc.ABC):
     @abc.abstractmethod
+    def __truediv__(self, key: str, /) -> Env:
+        """
+        Args:
+            key: a key to limit the scope to (only one layer at a time)
+
+        Returns:
+            an instance that is scoped to the given key
+
+        """
+        pass
+
+    @abc.abstractmethod
+    @deprecated("Use the / method for scoping")
     def scoped(self, prefix: str) -> Env:
         """
         Args:
@@ -17,43 +34,47 @@ class Env(abc.ABC):
         pass
 
     @overload
-    def get_string(
+    def get_string[T = str](
         self,
         key: str,
         *,
-        default: str,
+        default: T,
         required: bool = False,
-    ) -> str:
+        transform: Callable[[str], T] | None = None,
+    ) -> T:
         pass
 
     @overload
-    def get_string(
+    def get_string[T = str](
         self,
         key: str,
         *,
         default: None = None,
         required: Literal[False] = False,
-    ) -> str | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> T | None:
         pass
 
     @overload
-    def get_string(
+    def get_string[T = str](
         self,
         key: str,
         *,
         default: None = None,
         required: Literal[True],
-    ) -> str:
+        transform: Callable[[str], T] | None = None,
+    ) -> T:
         pass
 
     @abc.abstractmethod
-    def get_string(
+    def get_string[T = str](
         self,
         key: str,
         *,
-        default: str | None = None,
+        default: T | None = None,
         required: bool = False,
-    ) -> str | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> T | None:
         """
         Get a string value. The value is stripped and blank values are treated as
         missing.
@@ -62,6 +83,7 @@ class Env(abc.ABC):
             key: the key to look up
             default: a default value, defaults to None
             required: if True, a ValueError is raised instead of returning None
+            transform: a function to transform non-blank values
 
         Returns:
             The requested value, or the default value
@@ -140,48 +162,52 @@ class Env(abc.ABC):
 
         Raises:
             ValueError: 1) If the value is not a valid int. 2) If the value is missing,
-             the default is None, and required is True.
+                the default is None, and required is True.
         """
         pass
 
     @overload
-    def get_string_list(
+    def get_string_list[T = str](
         self,
         key: str,
         *,
-        default: list[str],
+        default: list[T],
         required: bool = False,
-    ) -> list[str]:
+        transform: Callable[[str], T] | None = None,
+    ) -> list[T]:
         pass
 
     @overload
-    def get_string_list(
+    def get_string_list[T = str](
         self,
         key: str,
         *,
         default: None = None,
         required: Literal[False] = False,
-    ) -> list[str] | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> list[T] | None:
         pass
 
     @overload
-    def get_string_list(
+    def get_string_list[T = str](
         self,
         key: str,
         *,
         default: None = None,
         required: Literal[True],
-    ) -> list[str]:
+        transform: Callable[[str], T] | None = None,
+    ) -> list[T]:
         pass
 
     @abc.abstractmethod
-    def get_string_list(
+    def get_string_list[T = str](
         self,
         key: str,
         *,
-        default: list[str] | None = None,
+        default: list[T] | None = None,
         required: bool = False,
-    ) -> list[str] | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> list[T] | None:
         """
         Gets a list of strings, splitting the original value by comma. For each value,
         the same rules as for ``get_string`` apply. Blank values are discarded.
@@ -194,6 +220,7 @@ class Env(abc.ABC):
             key: the key to look up
             default: a default value, defaults to None
             required: if True, a ValueError is raised instead of returning None
+            transform: a function to transform each list item
 
         Returns:
             a list of strings parsed from the value, or the default value
@@ -276,8 +303,8 @@ class Env(abc.ABC):
             include_env: whether to include the ``os.environ`` variables
             include_default_dotenv: whether to include the ``.env`` file (if it exists)
             additional_dotenvs: a list of other ``.env`` files to include. This should
-            just be the prefix, so "test" for "test.env". Descending precedence (last
-            one wins a conflict).
+                just be the prefix, so "test" for "test.env". Ascending precedence (last
+                one wins a conflict).
         """
         values = {}
 
@@ -343,19 +370,27 @@ class _BaseEnv(Env):
 
         return value
 
+    def __truediv__(self, key: str, /) -> Env:
+        if not key:
+            raise ValueError("Key cannot be empty")
+
+        return _ScopedEnv(self, f"{key}_")
+
+    @deprecated("Use / method for scoping")
     def scoped(self, prefix: str) -> Env:
         if not prefix:
             return self
 
         return _ScopedEnv(self, prefix)
 
-    def get_string(  # type: ignore[override]
+    def get_string[T = str](  # type: ignore[override]
         self,
         key: str,
         *,
-        default: str | None = None,
+        default: T | None = None,
         required: bool = False,
-    ) -> str | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> T | None:
         value = self._get_stripped_value(key)
         if value is None:
             if default is None and required:
@@ -363,7 +398,10 @@ class _BaseEnv(Env):
 
             return default
 
-        return value
+        if transform is None:
+            return value  # type: ignore[return-value]
+
+        return transform(value)
 
     def get_bool(  # type: ignore[override]
         self,
@@ -392,13 +430,14 @@ class _BaseEnv(Env):
 
         return int(value)
 
-    def get_string_list(  # type: ignore[override]
+    def get_string_list[T = str](  # type: ignore[override]
         self,
         key: str,
         *,
-        default: list[str] | None = None,
+        default: list[T] | None = None,
         required: bool = False,
-    ) -> list[str] | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> list[T] | None:
         values = self._get_stripped_value(key)
 
         if values is None:
@@ -406,7 +445,13 @@ class _BaseEnv(Env):
                 raise ValueError(f"Missing config value for {key}")
             return default
 
-        return [stripped for value in values.split(",") if (stripped := value.strip())]
+        raw_values = (
+            stripped for value in values.split(",") if (stripped := value.strip())
+        )
+        if transform is None:
+            return list(raw_values)  # type: ignore[arg-type]
+
+        return [transform(value) for value in raw_values]
 
     def get_int_list(  # type: ignore[override]
         self,
@@ -441,20 +486,29 @@ class _ScopedEnv(Env):
         self.parent = parent
         self.prefix = prefix
 
+    def __truediv__(self, key: str, /) -> Env:
+        if not key:
+            raise ValueError("Key cannot be empty")
+
+        return _ScopedEnv(self, f"{key}_")
+
+    @deprecated("Use / method for scoping")
     def scoped(self, prefix: str) -> Env:
         return _ScopedEnv(self, prefix)
 
-    def get_string(  # type: ignore[override]
+    def get_string[T = str](  # type: ignore[override]
         self,
         key: str,
         *,
-        default: str | None = None,
+        default: T | None = None,
         required: bool = False,
-    ) -> str | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> T | None:
         return self.parent.get_string(
             f"{self.prefix}{key}",
-            default=default,  # type: ignore[arg-type]
+            default=default,
             required=required,
+            transform=transform,
         )
 
     def get_bool(  # type: ignore[override]
@@ -478,17 +532,19 @@ class _ScopedEnv(Env):
             required=required,
         )
 
-    def get_string_list(  # type: ignore[override]
+    def get_string_list[T = str](  # type: ignore[override]
         self,
         key: str,
         *,
-        default: list[str] | None = None,
+        default: list[T] | None = None,
         required: bool = False,
-    ) -> list[str] | None:
+        transform: Callable[[str], T] | None = None,
+    ) -> list[T] | None:
         return self.parent.get_string_list(
             f"{self.prefix}{key}",
             default=default,  # type: ignore[arg-type]
             required=required,
+            transform=transform,
         )
 
     def get_int_list(  # type: ignore[override]
